#!/usr/bin/env python

from distutils.core import setup

setup(name='eta',
      version='0.9.2',
      description='ETA Progress bar for command-line utilities',
      author='Marcus Breese',
      author_email='marcus@breese.com',
      url='http://github.com/mbreese/eta/',
      packages=['eta'],
     )

